==> plasma-framework-5.79.0.tar.xz: plasma-framework-5.79.0/src/desktoptheme/breeze-light/metadata.desktop.cmake <==
[Desktop Entry]
Name=Breeze Light
Name[ar]=نسيم فاتح
Name[az]=Breze İşıqlı variant
Name[ca]=Brisa clara
Name[ca@valencia]=Brisa clara
Name[cs]=Breeze Světlé
Name[da]=Breeze Light
Name[de]=Breeze-Hell
Name[en_GB]=Breeze Light
Name[es]=Brisa claro
Name[et]=Breeze hele
Name[eu]=Breeze argia
Name[fi]=Breeze Light
Name[fr]=Breeze clair
Name[gd]=Oiteag shoilleir
Name[gl]=Breeze claro
Name[hu]=Breeze Light
Name[ia]=Brisa legier
Name[id]=Breeze Terang
Name[it]=Brezza chiaro
Name[ko]=밝은 Breeze
Name[lt]=Breeze šviesus
Name[lv]=Gaišā brīze
Name[nl]=Breeze Light
Name[nn]=Breeze lys
Name[pa]=ਬਰੀਜ਼ ਹਲਕਾ
Name[pl]=Jasna Bryza
Name[pt]=Brisa Clara
Name[pt_BR]=Breeze Light
Name[ro]=Briză, luminos
Name[ru]=Breeze, светлый вариант
Name[sk]=Vánok Svetlý
Name[sl]=Sapica (svetla) (Breeze Light)
Name[sr]=Поветарац лаки
Name[sr@ijekavian]=Поветарац лаки
Name[sr@ijekavianlatin]=Povetarac laki
Name[sr@latin]=Povetarac laki
Name[sv]=Breeze ljus
Name[tg]=Насими равшан
Name[tr]=Hafif Esinti
Name[uk]=Світла Breeze
Name[vi]=Breeze Sáng
Name[x-test]=xxBreeze Lightxx
Name[zh_CN]=亮色微风
Name[zh_TW]=Breeze Light
Comment=Breeze Light by the KDE VDG
Comment[az]=KDE VDG tərəfindən İşıqlı Breeze
Comment[ca]=Brisa clara, creat pel VDG del KDE
Comment[ca@valencia]=Brisa clara pel VDG del KDE
Comment[cs]=Breeze Light od KDE VDG
Comment[da]=Breeze Light af KDE VDG
Comment[de]=Breeze-Hell von der KDE VDG
Comment[en_GB]=Breeze Light by the KDE VDG
Comment[es]=Brisa claro por KDE VDG
Comment[et]=Breeze hele KDE VDG-lt
Comment[eu]=Breeze argia, KDE VDGk egina
Comment[fi]=Breeze Light KDE VDG:ltä
Comment[fr]=Breeze clair, par KDE VDG
Comment[gl]=Breeze claro de KDE VDG
Comment[hu]=Breeze Light a KDE VDG-től
Comment[ia]=Brisa legier per le KDE VDG
Comment[id]=Breeze Terang oleh KDE VDG
Comment[it]=Brezza chiaro del KDE VDG
Comment[ko]=KDE 시각 디자인 그룹에서 제작한 밝은 Breeze
Comment[lt]=Breeze šviesus pagal KDE VDG
Comment[nl]=Breeze Light door de KDE VDG
Comment[nn]=Breeze lys frå KDE VDG
Comment[pl]=Jasna Bryza autorstwa KDE VDG
Comment[pt]=Brisa Claro da VDG do KDE
Comment[pt_BR]=Breeze Light pelo KDE VDG
Comment[ro]=Briză, luminos, de KDE VDG
Comment[ru]=Светлый вариант Breeze от KDE VDG
Comment[sk]=Vánok Svetlý od KDE VDG
Comment[sl]=Sapica (svetla) (Breeze Light) od KDE VDG
Comment[sv]=Breeze ljus av KDE:s visuella designgrupp
Comment[tg]=Насими равшан аз KDE VDG
Comment[uk]=Світла Breeze, автори — KDE VDG
Comment[vi]=Breeze Sáng, do KDE VDG
Comment[x-test]=xxBreeze Light by the KDE VDGxx
Comment[zh_CN]=亮色微风，由 KDE VDG 创作
Comment[zh_TW]=由 KDE VDG 團隊製作的 Breeze Light


X-KDE-PluginInfo-Author=KDE Visual Design Group
X-KDE-PluginInfo-Email=kde-artists@kde.org
X-KDE-PluginInfo-Name=default
X-KDE-PluginInfo-Version=@KF_VERSION@
X-KDE-PluginInfo-Website=https://plasma.kde.org
X-KDE-PluginInfo-Category=
X-KDE-PluginInfo-License=LGPL
X-KDE-PluginInfo-EnabledByDefault=true
X-Plasma-API=5.0

[Wallpaper]
defaultWallpaperTheme=Next
defaultFileSuffix=.png
defaultWidth=1920
defaultHeight=1080

[ContrastEffect]
enabled=true
contrast=0.2
intensity=2.0
saturation=1.7

==> plasma-framework-5.90.0.tar.xz: plasma-framework-5.90.0/src/desktoptheme/breeze-light/metadata.desktop.cmake <==
[Desktop Entry]
Name=Breeze Light
Name[ar]=نسيم فاتح
Name[az]=Breze İşıqlı variant
Name[ca]=Brisa clara
Name[ca@valencia]=Brisa clara
Name[cs]=Breeze Světlé
Name[da]=Breeze Light
Name[de]=Breeze-Hell
Name[en_GB]=Breeze Light
Name[es]=Brisa claro
Name[et]=Breeze hele
Name[eu]=Breeze argia
Name[fi]=Breeze Light
Name[fr]=Breeze clair
Name[gd]=Oiteag shoilleir
Name[gl]=Breeze claro
Name[hu]=Breeze Light
Name[ia]=Brisa legier
Name[id]=Breeze Terang
Name[it]=Brezza chiaro
Name[ko]=밝은 Breeze
Name[lt]=Breeze šviesus
Name[lv]=Gaišā brīze
Name[nl]=Breeze Light
Name[nn]=Breeze lys
Name[pa]=ਬਰੀਜ਼ ਹਲਕਾ
Name[pl]=Jasna Bryza
Name[pt]=Brisa Clara
Name[pt_BR]=Breeze Light
Name[ro]=Briză, luminos
Name[ru]=Breeze, светлый вариант
Name[sk]=Vánok Svetlý
Name[sl]=Sapica (svetla) (Breeze Light)
Name[sr]=Поветарац лаки
Name[sr@ijekavian]=Поветарац лаки
Name[sr@ijekavianlatin]=Povetarac laki
Name[sr@latin]=Povetarac laki
Name[sv]=Breeze ljus
Name[tg]=Насими равшан
Name[tr]=Hafif Esinti
Name[uk]=Світла Breeze
Name[vi]=Breeze Sáng
Name[x-test]=xxBreeze Lightxx
Name[zh_CN]=Breeze 微风浅色
Name[zh_TW]=Breeze Light
Comment=Breeze Light by the KDE VDG
Comment[ar]=نسيم فاتح من مجموعة تصميم كدي
Comment[az]=KDE VDG tərəfindən İşıqlı Breeze
Comment[ca]=Brisa clara, creat pel VDG del KDE
Comment[ca@valencia]=Brisa clara, creat pel VDG del KDE
Comment[cs]=Breeze Light od KDE VDG
Comment[da]=Breeze Light af KDE VDG
Comment[de]=Breeze-Hell von der KDE VDG
Comment[en_GB]=Breeze Light by the KDE VDG
Comment[es]=Brisa claro por KDE VDG
Comment[et]=Breeze hele KDE VDG-lt
Comment[eu]=Breeze argia, KDE VDGk egina
Comment[fi]=Breeze Light KDE VDG:ltä
Comment[fr]=Breeze clair, par KDE VDG
Comment[gl]=Breeze claro de KDE VDG
Comment[hu]=Breeze Light a KDE VDG-től
Comment[ia]=Brisa legier per le KDE VDG
Comment[id]=Breeze Terang oleh KDE VDG
Comment[it]=Brezza chiaro del KDE VDG
Comment[ko]=KDE 시각 디자인 그룹에서 제작한 밝은 Breeze
Comment[lt]=Breeze šviesus pagal KDE VDG
Comment[nl]=Breeze Light door de KDE VDG
Comment[nn]=Breeze lys frå KDE VDG
Comment[pl]=Jasna Bryza autorstwa KDE VDG
Comment[pt]=Brisa Claro da VDG do KDE
Comment[pt_BR]=Breeze Light pelo KDE VDG
Comment[ro]=Briză, luminos, de KDE VDG
Comment[ru]=Светлый вариант Breeze от KDE VDG
Comment[sk]=Vánok Svetlý od KDE VDG
Comment[sl]=Sapica (svetla) (Breeze Light) od KDE VDG
Comment[sv]=Breeze ljus av KDE:s visuella designgrupp
Comment[tg]=Насими равшан аз KDE VDG
Comment[uk]=Світла Breeze, автори — KDE VDG
Comment[vi]=Breeze Sáng, do KDE VDG
Comment[x-test]=xxBreeze Light by the KDE VDGxx
Comment[zh_CN]=Breeze 微风浅色主题，由 KDE VDG (视觉设计团队) 设计制作
Comment[zh_TW]=由 KDE VDG 團隊製作的 Breeze Light


X-KDE-PluginInfo-Author=KDE Visual Design Group
X-KDE-PluginInfo-Email=kde-artists@kde.org
X-KDE-PluginInfo-Name=default
X-KDE-PluginInfo-Version=@KF_VERSION@
X-KDE-PluginInfo-Website=https://plasma.kde.org
X-KDE-PluginInfo-Category=
X-KDE-PluginInfo-License=LGPL
X-KDE-PluginInfo-EnabledByDefault=true
X-Plasma-API=5.0

[Wallpaper]
defaultWallpaperTheme=Next
defaultFileSuffix=.png
defaultWidth=1920
defaultHeight=1080

[ContrastEffect]
enabled=true
contrast=0.17
intensity=1.25
saturation=9

[AdaptiveTransparency]
enabled=true
